package Search::Elasticsearch::Role::Is_Async;
$Search::Elasticsearch::Role::Is_Async::VERSION = '6.80_01'; # TRIAL

$Search::Elasticsearch::Role::Is_Async::VERSION = '6.8001';use Moo::Role;
use namespace::clean;

1;

# ABSTRACT: A role to mark classes which should be used with other async classes

__END__

=pod

=encoding UTF-8

=head1 NAME

Search::Elasticsearch::Role::Is_Async - A role to mark classes which should be used with other async classes

=head1 VERSION

version 6.80_01

=head1 AUTHOR

Enrico Zimuel <enrico.zimuel@elastic.co>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2020 by Elasticsearch BV.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
